# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_twofactor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_twofactor.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dsteammessages_twofactor.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n\x19\x43TwoFactor_Status_Request\x12#\n\x07steamid\x18\x01 \x01(\x06\x42\x12\x82\xb5\x18\x0esteamid to use\"\xc6\x07\n\x1a\x43TwoFactor_Status_Response\x12&\n\x05state\x18\x01 \x01(\rB\x17\x82\xb5\x18\x13\x41uthenticator state\x12=\n\x13inactivation_reason\x18\x02 \x01(\rB \x82\xb5\x18\x1cInactivation reason (if any)\x12\x35\n\x12\x61uthenticator_type\x18\x03 \x01(\rB\x19\x82\xb5\x18\x15Type of authenticator\x12L\n\x15\x61uthenticator_allowed\x18\x04 \x01(\x08\x42-\x82\xb5\x18)Account allowed to have an authenticator?\x12;\n\x11steamguard_scheme\x18\x05 \x01(\rB \x82\xb5\x18\x1cSteam Guard scheme in effect\x12\x41\n\ttoken_gid\x18\x06 \x01(\tB.\x82\xb5\x18*String rep of token GID assigned by server\x12\x42\n\x0f\x65mail_validated\x18\x07 \x01(\x08\x42)\x82\xb5\x18%Account has verified email capability\x12?\n\x11\x64\x65vice_identifier\x18\x08 \x01(\tB$\x82\xb5\x18 Authenticator (phone) identifier\x12\x34\n\x0ctime_created\x18\t \x01(\rB\x1e\x82\xb5\x18\x1aWhen the token was created\x12W\n\x1drevocation_attempts_remaining\x18\n \x01(\rB0\x82\xb5\x18,Number of revocation code attempts remaining\x12^\n\x10\x63lassified_agent\x18\x0b \x01(\tBD\x82\xb5\x18@Agent that added the authenticator (e.g., ios / android / other)\x12g\n\x1c\x61llow_external_authenticator\x18\x0c \x01(\x08\x42\x41\x82\xb5\x18=Allow a third-party authenticator (in addition to two-factor)\x12_\n\x10time_transferred\x18\r \x01(\rBE\x82\xb5\x18\x41When the token was transferred from another device, if applicable\"\xf3\x03\n#CTwoFactor_AddAuthenticator_Request\x12#\n\x07steamid\x18\x01 \x01(\x06\x42\x12\x82\xb5\x18\x0esteamid to use\x12:\n\x12\x61uthenticator_time\x18\x02 \x01(\x04\x42\x1e\x82\xb5\x18\x1a\x43urrent authenticator time\x12?\n\rserial_number\x18\x03 \x01(\x06\x42(\x82\xb5\x18$locally computed serial (deprecated)\x12\x32\n\x12\x61uthenticator_type\x18\x04 \x01(\rB\x16\x82\xb5\x18\x12\x41uthenticator type\x12\x37\n\x11\x64\x65vice_identifier\x18\x05 \x01(\tB\x1c\x82\xb5\x18\x18\x41uthenticator identifier\x12\x41\n\x0csms_phone_id\x18\x06 \x01(\tB+\x82\xb5\x18\'ID of phone to use for SMS verification\x12\x39\n\x0chttp_headers\x18\x07 \x03(\tB#\x82\xb5\x18\x1fHTTP headers alternating by K/V\x12?\n\x07version\x18\x08 \x01(\r:\x01\x31\x42+\x82\xb5\x18\'What the version of our token should be\"\xca\x05\n$CTwoFactor_AddAuthenticator_Response\x12I\n\rshared_secret\x18\x01 \x01(\x0c\x42\x32\x82\xb5\x18.Shared secret between server and authenticator\x12I\n\rserial_number\x18\x02 \x01(\x06\x42\x32\x82\xb5\x18.Authenticator serial number (unique per token)\x12>\n\x0frevocation_code\x18\x03 \x01(\tB%\x82\xb5\x18!code used to revoke authenticator\x12+\n\x03uri\x18\x04 \x01(\tB\x1e\x82\xb5\x18\x1aURI for QR code generation\x12,\n\x0bserver_time\x18\x05 \x01(\x04\x42\x17\x82\xb5\x18\x13\x43urrent server time\x12\x41\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\tB+\x82\xb5\x18\'Account name to display on token client\x12\x33\n\ttoken_gid\x18\x07 \x01(\tB \x82\xb5\x18\x1cToken GID assigned by server\x12V\n\x0fidentity_secret\x18\x08 \x01(\x0c\x42=\x82\xb5\x18\x39Secret used for identity attestation (e.g., for eventing)\x12)\n\x08secret_1\x18\t \x01(\x0c\x42\x17\x82\xb5\x18\x13Spare shared secret\x12\x1f\n\x06status\x18\n \x01(\x05\x42\x0f\x82\xb5\x18\x0bResult code\x12U\n\x11phone_number_hint\x18\x0b \x01(\tB:\x82\xb5\x18\x36\x61 portion of the phone number the SMS code was sent to\"\xdd\x01\n\x1c\x43TwoFactor_SendEmail_Request\x12#\n\x07steamid\x18\x01 \x01(\x06\x42\x12\x82\xb5\x18\x0eSteamid to use\x12\x46\n\nemail_type\x18\x02 \x01(\rB2\x82\xb5\x18.Type of email to send (ETwoFactorEmailType::*)\x12P\n\x17include_activation_code\x18\x03 \x01(\x08\x42/\x82\xb5\x18+Include activation code in email parameters\"\x1f\n\x1d\x43TwoFactor_SendEmail_Response\"\xc7\x03\n+CTwoFactor_FinalizeAddAuthenticator_Request\x12#\n\x07steamid\x18\x01 \x01(\x06\x42\x12\x82\xb5\x18\x0esteamid to use\x12\x31\n\x12\x61uthenticator_code\x18\x02 \x01(\tB\x15\x82\xb5\x18\x11\x43urrent auth code\x12:\n\x12\x61uthenticator_time\x18\x03 \x01(\x04\x42\x1e\x82\xb5\x18\x1a\x43urrent authenticator time\x12\x45\n\x0f\x61\x63tivation_code\x18\x04 \x01(\tB,\x82\xb5\x18(Activation code from out-of-band message\x12\x39\n\x0chttp_headers\x18\x05 \x03(\tB#\x82\xb5\x18\x1fHTTP headers alternating by K/V\x12\x81\x01\n\x11validate_sms_code\x18\x06 \x01(\x08\x42\x66\x82\xb5\x18\x62When finalizing with an SMS code, pass the request on to the PhoneService to update its state too.\"\xe9\x01\n,CTwoFactor_FinalizeAddAuthenticator_Response\x12:\n\x07success\x18\x01 \x01(\x08\x42)\x82\xb5\x18%True if succeeded, or want more tries\x12.\n\twant_more\x18\x02 \x01(\x08\x42\x1b\x82\xb5\x18\x17True if want more tries\x12,\n\x0bserver_time\x18\x03 \x01(\x04\x42\x17\x82\xb5\x18\x13\x43urrent server time\x12\x1f\n\x06status\x18\x04 \x01(\x05\x42\x0f\x82\xb5\x18\x0bResult code\"\xb2\x01\n%CTwoFactor_UpdateTokenVersion_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12<\n\x07version\x18\x02 \x01(\rB+\x82\xb5\x18\'What the version of our token should be\x12:\n\tsignature\x18\x03 \x01(\x0c\x42\'\x82\xb5\x18#HMAC digest over user\'s private key\"(\n&CTwoFactor_UpdateTokenVersion_Response\"\xcb\x02\n&CTwoFactor_RemoveAuthenticator_Request\x12<\n\x0frevocation_code\x18\x02 \x01(\tB#\x82\xb5\x18\x1fPassword needed to remove token\x12H\n\x11revocation_reason\x18\x05 \x01(\rB-\x82\xb5\x18)Reason the authenticator is being removed\x12O\n\x11steamguard_scheme\x18\x06 \x01(\rB4\x82\xb5\x18\x30Type of Steam Guard to use once token is removed\x12H\n\x1dremove_all_steamguard_cookies\x18\x07 \x01(\x08\x42!\x82\xb5\x18\x1dRemove all steamguard cookies\"\xfe\x01\n\'CTwoFactor_RemoveAuthenticator_Response\x12L\n\x07success\x18\x01 \x01(\x08\x42;\x82\xb5\x18\x37True if request succeeeded. The mobile app checks this.\x12,\n\x0bserver_time\x18\x03 \x01(\x04\x42\x17\x82\xb5\x18\x13\x43urrent server time\x12W\n\x1drevocation_attempts_remaining\x18\x05 \x01(\rB0\x82\xb5\x18,Number of revocation code attempts remaining\"7\n\'CTwoFactor_CreateEmergencyCodes_Request\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"N\n(CTwoFactor_CreateEmergencyCodes_Response\x12\"\n\x05\x63odes\x18\x01 \x03(\tB\x13\x82\xb5\x18\x0f\x45mergency codes\"O\n(CTwoFactor_DestroyEmergencyCodes_Request\x12#\n\x07steamid\x18\x01 \x01(\x06\x42\x12\x82\xb5\x18\x0esteamid to use\"+\n)CTwoFactor_DestroyEmergencyCodes_Response\"F\n CTwoFactor_ValidateToken_Request\x12\"\n\x04\x63ode\x18\x01 \x01(\tB\x14\x82\xb5\x18\x10\x63ode to validate\"L\n!CTwoFactor_ValidateToken_Response\x12\'\n\x05valid\x18\x01 \x01(\x08\x42\x18\x82\xb5\x18\x14result of validation\"9\n7CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\"\x91\x01\n8CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\x12U\n\x07success\x18\x01 \x01(\x08\x42\x44\x82\xb5\x18@True if succeeded, or want more tries with an authenticator_code\"\xb3\x01\n:CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x12#\n\x08sms_code\x18\x01 \x01(\tB\x11\x82\xb5\x18\rCode from SMS\x12P\n\x12generate_new_token\x18\x02 \x01(\x08\x42\x34\x82\xb5\x18\x30Generate new token (instead of removing old one)\"\x8d\x06\n:CRemoveAuthenticatorViaChallengeContinue_Replacement_Token\x12I\n\rshared_secret\x18\x01 \x01(\x0c\x42\x32\x82\xb5\x18.Shared secret between server and authenticator\x12I\n\rserial_number\x18\x02 \x01(\x06\x42\x32\x82\xb5\x18.Authenticator serial number (unique per token)\x12>\n\x0frevocation_code\x18\x03 \x01(\tB%\x82\xb5\x18!code used to revoke authenticator\x12+\n\x03uri\x18\x04 \x01(\tB\x1e\x82\xb5\x18\x1aURI for QR code generation\x12,\n\x0bserver_time\x18\x05 \x01(\x04\x42\x17\x82\xb5\x18\x13\x43urrent server time\x12\x41\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\tB+\x82\xb5\x18\'Account name to display on token client\x12\x33\n\ttoken_gid\x18\x07 \x01(\tB \x82\xb5\x18\x1cToken GID assigned by server\x12V\n\x0fidentity_secret\x18\x08 \x01(\x0c\x42=\x82\xb5\x18\x39Secret used for identity attestation (e.g., for eventing)\x12)\n\x08secret_1\x18\t \x01(\x0c\x42\x17\x82\xb5\x18\x13Spare shared secret\x12\x1f\n\x06status\x18\n \x01(\x05\x42\x0f\x82\xb5\x18\x0bResult code\x12O\n\x11steamguard_scheme\x18\x0b \x01(\rB4\x82\xb5\x18\x30Type of Steam Guard to use once token is removed\x12\x31\n\x07steamid\x18\x0c \x01(\x06\x42 \x82\xb5\x18\x1csteamid that owns the secret\"\x89\x02\n;CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response\x12U\n\x07success\x18\x01 \x01(\x08\x42\x44\x82\xb5\x18@True if succeeded, or want more tries with an authenticator_code\x12s\n\x11replacement_token\x18\x02 \x01(\x0b\x32;.CRemoveAuthenticatorViaChallengeContinue_Replacement_TokenB\x1b\x82\xb5\x18\x17\x46resh secret to install2\xbb\x0e\n\tTwoFactor\x12\x8c\x01\n\x0bQueryStatus\x12\x1a.CTwoFactor_Status_Request\x1a\x1b.CTwoFactor_Status_Response\"D\x82\xb5\x18@Get two-factor authentication settings for the logged-in account\x12\x9a\x01\n\x10\x41\x64\x64\x41uthenticator\x12$.CTwoFactor_AddAuthenticator_Request\x1a%.CTwoFactor_AddAuthenticator_Response\"9\x82\xb5\x18\x35\x41\x64\x64 two-factor authenticator to the logged-in account\x12i\n\tSendEmail\x12\x1d.CTwoFactor_SendEmail_Request\x1a\x1e.CTwoFactor_SendEmail_Response\"\x1d\x82\xb5\x18\x19Send email to the account\x12\xc1\x01\n\x18\x46inalizeAddAuthenticator\x12,.CTwoFactor_FinalizeAddAuthenticator_Request\x1a-.CTwoFactor_FinalizeAddAuthenticator_Response\"H\x82\xb5\x18\x44\x46inalize two-factor authentication addition to the logged-in account\x12\x8a\x01\n\x12UpdateTokenVersion\x12&.CTwoFactor_UpdateTokenVersion_Request\x1a\'.CTwoFactor_UpdateTokenVersion_Response\"#\x82\xb5\x18\x1fUpdate the version for my token\x12\xb2\x01\n\x13RemoveAuthenticator\x12\'.CTwoFactor_RemoveAuthenticator_Request\x1a(.CTwoFactor_RemoveAuthenticator_Response\"H\x82\xb5\x18\x44Remove two-factor authentication addition from the logged-in account\x12\x97\x01\n\x14\x43reateEmergencyCodes\x12(.CTwoFactor_CreateEmergencyCodes_Request\x1a).CTwoFactor_CreateEmergencyCodes_Response\"*\x82\xb5\x18&Generate emergency authenticator codes\x12\xa9\x01\n\x15\x44\x65stroyEmergencyCodes\x12).CTwoFactor_DestroyEmergencyCodes_Request\x1a*.CTwoFactor_DestroyEmergencyCodes_Response\"9\x82\xb5\x18\x35\x44\x65stroy emergency authenticator codes for the account\x12z\n\rValidateToken\x12!.CTwoFactor_ValidateToken_Request\x1a\".CTwoFactor_ValidateToken_Response\"\"\x82\xb5\x18\x1eValidate (and consume) a token\x12\xcc\x01\n$RemoveAuthenticatorViaChallengeStart\x12\x38.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\x1a\x39.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\"/\x82\xb5\x18+Start challenge-based authenticator removal\x12\xd8\x01\n\'RemoveAuthenticatorViaChallengeContinue\x12;.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x1a<.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response\"2\x82\xb5\x18.Continue challenge-based authenticator removal\x1a%\x82\xb5\x18!Two Factor Authentication ServiceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CTWOFACTOR_STATUS_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_Status_Request',
  full_name='CTwoFactor_Status_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_Status_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016steamid to use', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=157,
)


_CTWOFACTOR_STATUS_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_Status_Response',
  full_name='CTwoFactor_Status_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CTwoFactor_Status_Response.state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Authenticator state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inactivation_reason', full_name='CTwoFactor_Status_Response.inactivation_reason', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Inactivation reason (if any)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_type', full_name='CTwoFactor_Status_Response.authenticator_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025Type of authenticator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_allowed', full_name='CTwoFactor_Status_Response.authenticator_allowed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Account allowed to have an authenticator?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_scheme', full_name='CTwoFactor_Status_Response.steamguard_scheme', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Steam Guard scheme in effect', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_gid', full_name='CTwoFactor_Status_Response.token_gid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*String rep of token GID assigned by server', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_validated', full_name='CTwoFactor_Status_Response.email_validated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Account has verified email capability', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_identifier', full_name='CTwoFactor_Status_Response.device_identifier', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 Authenticator (phone) identifier', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CTwoFactor_Status_Response.time_created', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032When the token was created', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revocation_attempts_remaining', full_name='CTwoFactor_Status_Response.revocation_attempts_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030,Number of revocation code attempts remaining', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classified_agent', full_name='CTwoFactor_Status_Response.classified_agent', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@Agent that added the authenticator (e.g., ios / android / other)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_external_authenticator', full_name='CTwoFactor_Status_Response.allow_external_authenticator', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030=Allow a third-party authenticator (in addition to two-factor)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_transferred', full_name='CTwoFactor_Status_Response.time_transferred', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030AWhen the token was transferred from another device, if applicable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=1126,
)


_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_AddAuthenticator_Request',
  full_name='CTwoFactor_AddAuthenticator_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_AddAuthenticator_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016steamid to use', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_time', full_name='CTwoFactor_AddAuthenticator_Request.authenticator_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032Current authenticator time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CTwoFactor_AddAuthenticator_Request.serial_number', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$locally computed serial (deprecated)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_type', full_name='CTwoFactor_AddAuthenticator_Request.authenticator_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\022Authenticator type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_identifier', full_name='CTwoFactor_AddAuthenticator_Request.device_identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030Authenticator identifier', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sms_phone_id', full_name='CTwoFactor_AddAuthenticator_Request.sms_phone_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'ID of phone to use for SMS verification', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_headers', full_name='CTwoFactor_AddAuthenticator_Request.http_headers', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037HTTP headers alternating by K/V', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CTwoFactor_AddAuthenticator_Request.version', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'What the version of our token should be', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1628,
)


_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_AddAuthenticator_Response',
  full_name='CTwoFactor_AddAuthenticator_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shared_secret', full_name='CTwoFactor_AddAuthenticator_Response.shared_secret', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Shared secret between server and authenticator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CTwoFactor_AddAuthenticator_Response.serial_number', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Authenticator serial number (unique per token)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revocation_code', full_name='CTwoFactor_AddAuthenticator_Response.revocation_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!code used to revoke authenticator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='CTwoFactor_AddAuthenticator_Response.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032URI for QR code generation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CTwoFactor_AddAuthenticator_Response.server_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Current server time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CTwoFactor_AddAuthenticator_Response.account_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Account name to display on token client', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_gid', full_name='CTwoFactor_AddAuthenticator_Response.token_gid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Token GID assigned by server', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_secret', full_name='CTwoFactor_AddAuthenticator_Response.identity_secret', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309Secret used for identity attestation (e.g., for eventing)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_1', full_name='CTwoFactor_AddAuthenticator_Response.secret_1', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Spare shared secret', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CTwoFactor_AddAuthenticator_Response.status', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\013Result code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone_number_hint', full_name='CTwoFactor_AddAuthenticator_Response.phone_number_hint', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306a portion of the phone number the SMS code was sent to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=2345,
)


_CTWOFACTOR_SENDEMAIL_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_SendEmail_Request',
  full_name='CTwoFactor_SendEmail_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_SendEmail_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016Steamid to use', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_type', full_name='CTwoFactor_SendEmail_Request.email_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Type of email to send (ETwoFactorEmailType::*)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_activation_code', full_name='CTwoFactor_SendEmail_Request.include_activation_code', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+Include activation code in email parameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2569,
)


_CTWOFACTOR_SENDEMAIL_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_SendEmail_Response',
  full_name='CTwoFactor_SendEmail_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2571,
  serialized_end=2602,
)


_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_FinalizeAddAuthenticator_Request',
  full_name='CTwoFactor_FinalizeAddAuthenticator_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016steamid to use', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_code', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.authenticator_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021Current auth code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticator_time', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.authenticator_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032Current authenticator time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.activation_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030(Activation code from out-of-band message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_headers', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.http_headers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037HTTP headers alternating by K/V', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validate_sms_code', full_name='CTwoFactor_FinalizeAddAuthenticator_Request.validate_sms_code', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030bWhen finalizing with an SMS code, pass the request on to the PhoneService to update its state too.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=3060,
)


_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_FinalizeAddAuthenticator_Response',
  full_name='CTwoFactor_FinalizeAddAuthenticator_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CTwoFactor_FinalizeAddAuthenticator_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%True if succeeded, or want more tries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='want_more', full_name='CTwoFactor_FinalizeAddAuthenticator_Response.want_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027True if want more tries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CTwoFactor_FinalizeAddAuthenticator_Response.server_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Current server time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CTwoFactor_FinalizeAddAuthenticator_Response.status', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\013Result code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3063,
  serialized_end=3296,
)


_CTWOFACTOR_UPDATETOKENVERSION_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_UpdateTokenVersion_Request',
  full_name='CTwoFactor_UpdateTokenVersion_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_UpdateTokenVersion_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CTwoFactor_UpdateTokenVersion_Request.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'What the version of our token should be', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='CTwoFactor_UpdateTokenVersion_Request.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#HMAC digest over user\'s private key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3299,
  serialized_end=3477,
)


_CTWOFACTOR_UPDATETOKENVERSION_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_UpdateTokenVersion_Response',
  full_name='CTwoFactor_UpdateTokenVersion_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3479,
  serialized_end=3519,
)


_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticator_Request',
  full_name='CTwoFactor_RemoveAuthenticator_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='revocation_code', full_name='CTwoFactor_RemoveAuthenticator_Request.revocation_code', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Password needed to remove token', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revocation_reason', full_name='CTwoFactor_RemoveAuthenticator_Request.revocation_reason', index=1,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Reason the authenticator is being removed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_scheme', full_name='CTwoFactor_RemoveAuthenticator_Request.steamguard_scheme', index=2,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Type of Steam Guard to use once token is removed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_all_steamguard_cookies', full_name='CTwoFactor_RemoveAuthenticator_Request.remove_all_steamguard_cookies', index=3,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Remove all steamguard cookies', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3522,
  serialized_end=3853,
)


_CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticator_Response',
  full_name='CTwoFactor_RemoveAuthenticator_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CTwoFactor_RemoveAuthenticator_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307True if request succeeeded. The mobile app checks this.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CTwoFactor_RemoveAuthenticator_Response.server_time', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Current server time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revocation_attempts_remaining', full_name='CTwoFactor_RemoveAuthenticator_Response.revocation_attempts_remaining', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030,Number of revocation code attempts remaining', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3856,
  serialized_end=4110,
)


_CTWOFACTOR_CREATEEMERGENCYCODES_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_CreateEmergencyCodes_Request',
  full_name='CTwoFactor_CreateEmergencyCodes_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='CTwoFactor_CreateEmergencyCodes_Request.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4112,
  serialized_end=4167,
)


_CTWOFACTOR_CREATEEMERGENCYCODES_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_CreateEmergencyCodes_Response',
  full_name='CTwoFactor_CreateEmergencyCodes_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codes', full_name='CTwoFactor_CreateEmergencyCodes_Response.codes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\017Emergency codes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4169,
  serialized_end=4247,
)


_CTWOFACTOR_DESTROYEMERGENCYCODES_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_DestroyEmergencyCodes_Request',
  full_name='CTwoFactor_DestroyEmergencyCodes_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CTwoFactor_DestroyEmergencyCodes_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016steamid to use', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4249,
  serialized_end=4328,
)


_CTWOFACTOR_DESTROYEMERGENCYCODES_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_DestroyEmergencyCodes_Response',
  full_name='CTwoFactor_DestroyEmergencyCodes_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4330,
  serialized_end=4373,
)


_CTWOFACTOR_VALIDATETOKEN_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_ValidateToken_Request',
  full_name='CTwoFactor_ValidateToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='CTwoFactor_ValidateToken_Request.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020code to validate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4375,
  serialized_end=4445,
)


_CTWOFACTOR_VALIDATETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_ValidateToken_Response',
  full_name='CTwoFactor_ValidateToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='CTwoFactor_ValidateToken_Response.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024result of validation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4447,
  serialized_end=4523,
)


_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request',
  full_name='CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4525,
  serialized_end=4582,
)


_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response',
  full_name='CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@True if succeeded, or want more tries with an authenticator_code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4585,
  serialized_end=4730,
)


_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request',
  full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sms_code', full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request.sms_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\rCode from SMS', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generate_new_token', full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request.generate_new_token', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Generate new token (instead of removing old one)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4733,
  serialized_end=4912,
)


_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN = _descriptor.Descriptor(
  name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token',
  full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shared_secret', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.shared_secret', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Shared secret between server and authenticator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.serial_number', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.Authenticator serial number (unique per token)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revocation_code', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.revocation_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!code used to revoke authenticator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032URI for QR code generation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.server_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Current server time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.account_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'Account name to display on token client', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_gid', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.token_gid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034Token GID assigned by server', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_secret', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.identity_secret', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309Secret used for identity attestation (e.g., for eventing)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_1', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.secret_1', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Spare shared secret', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.status', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\013Result code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_scheme', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.steamguard_scheme', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300Type of Steam Guard to use once token is removed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CRemoveAuthenticatorViaChallengeContinue_Replacement_Token.steamid', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034steamid that owns the secret', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4915,
  serialized_end=5696,
)


_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE = _descriptor.Descriptor(
  name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response',
  full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030@True if succeeded, or want more tries with an authenticator_code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replacement_token', full_name='CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response.replacement_token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027Fresh secret to install', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5699,
  serialized_end=5964,
)

_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE.fields_by_name['replacement_token'].message_type = _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN
DESCRIPTOR.message_types_by_name['CTwoFactor_Status_Request'] = _CTWOFACTOR_STATUS_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_Status_Response'] = _CTWOFACTOR_STATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_AddAuthenticator_Request'] = _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_AddAuthenticator_Response'] = _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_SendEmail_Request'] = _CTWOFACTOR_SENDEMAIL_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_SendEmail_Response'] = _CTWOFACTOR_SENDEMAIL_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_FinalizeAddAuthenticator_Request'] = _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_FinalizeAddAuthenticator_Response'] = _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_UpdateTokenVersion_Request'] = _CTWOFACTOR_UPDATETOKENVERSION_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_UpdateTokenVersion_Response'] = _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticator_Request'] = _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticator_Response'] = _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_CreateEmergencyCodes_Request'] = _CTWOFACTOR_CREATEEMERGENCYCODES_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_CreateEmergencyCodes_Response'] = _CTWOFACTOR_CREATEEMERGENCYCODES_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_DestroyEmergencyCodes_Request'] = _CTWOFACTOR_DESTROYEMERGENCYCODES_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_DestroyEmergencyCodes_Response'] = _CTWOFACTOR_DESTROYEMERGENCYCODES_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_ValidateToken_Request'] = _CTWOFACTOR_VALIDATETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_ValidateToken_Response'] = _CTWOFACTOR_VALIDATETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request'] = _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response'] = _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request'] = _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST
DESCRIPTOR.message_types_by_name['CRemoveAuthenticatorViaChallengeContinue_Replacement_Token'] = _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN
DESCRIPTOR.message_types_by_name['CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response'] = _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CTwoFactor_Status_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_Status_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_STATUS_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_Status_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_Status_Request)

CTwoFactor_Status_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_Status_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_STATUS_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_Status_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_Status_Response)

CTwoFactor_AddAuthenticator_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_AddAuthenticator_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_AddAuthenticator_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_AddAuthenticator_Request)

CTwoFactor_AddAuthenticator_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_AddAuthenticator_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_AddAuthenticator_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_AddAuthenticator_Response)

CTwoFactor_SendEmail_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_SendEmail_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_SENDEMAIL_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_SendEmail_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_SendEmail_Request)

CTwoFactor_SendEmail_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_SendEmail_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_SENDEMAIL_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_SendEmail_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_SendEmail_Response)

CTwoFactor_FinalizeAddAuthenticator_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_FinalizeAddAuthenticator_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_FinalizeAddAuthenticator_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_FinalizeAddAuthenticator_Request)

CTwoFactor_FinalizeAddAuthenticator_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_FinalizeAddAuthenticator_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_FinalizeAddAuthenticator_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_FinalizeAddAuthenticator_Response)

CTwoFactor_UpdateTokenVersion_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_UpdateTokenVersion_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_UPDATETOKENVERSION_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_UpdateTokenVersion_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_UpdateTokenVersion_Request)

CTwoFactor_UpdateTokenVersion_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_UpdateTokenVersion_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_UpdateTokenVersion_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_UpdateTokenVersion_Response)

CTwoFactor_RemoveAuthenticator_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticator_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticator_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticator_Request)

CTwoFactor_RemoveAuthenticator_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticator_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticator_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticator_Response)

CTwoFactor_CreateEmergencyCodes_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_CreateEmergencyCodes_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_CREATEEMERGENCYCODES_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_CreateEmergencyCodes_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_CreateEmergencyCodes_Request)

CTwoFactor_CreateEmergencyCodes_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_CreateEmergencyCodes_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_CREATEEMERGENCYCODES_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_CreateEmergencyCodes_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_CreateEmergencyCodes_Response)

CTwoFactor_DestroyEmergencyCodes_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_DestroyEmergencyCodes_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_DESTROYEMERGENCYCODES_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_DestroyEmergencyCodes_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_DestroyEmergencyCodes_Request)

CTwoFactor_DestroyEmergencyCodes_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_DestroyEmergencyCodes_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_DESTROYEMERGENCYCODES_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_DestroyEmergencyCodes_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_DestroyEmergencyCodes_Response)

CTwoFactor_ValidateToken_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_ValidateToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_VALIDATETOKEN_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_ValidateToken_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_ValidateToken_Request)

CTwoFactor_ValidateToken_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_ValidateToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_VALIDATETOKEN_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_ValidateToken_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_ValidateToken_Response)

CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request)

CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response)

CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request)

CRemoveAuthenticatorViaChallengeContinue_Replacement_Token = _reflection.GeneratedProtocolMessageType('CRemoveAuthenticatorViaChallengeContinue_Replacement_Token', (_message.Message,), {
  'DESCRIPTOR' : _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CRemoveAuthenticatorViaChallengeContinue_Replacement_Token)
  })
_sym_db.RegisterMessage(CRemoveAuthenticatorViaChallengeContinue_Replacement_Token)

CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response = _reflection.GeneratedProtocolMessageType('CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response', (_message.Message,), {
  'DESCRIPTOR' : _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE,
  '__module__' : 'steammessages_twofactor_pb2'
  # @@protoc_insertion_point(class_scope:CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response)
  })
_sym_db.RegisterMessage(CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response)


DESCRIPTOR._options = None
_CTWOFACTOR_STATUS_REQUEST.fields_by_name['steamid']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['state']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['inactivation_reason']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['authenticator_type']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['authenticator_allowed']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['steamguard_scheme']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['token_gid']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['email_validated']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['device_identifier']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['time_created']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['revocation_attempts_remaining']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['classified_agent']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['allow_external_authenticator']._options = None
_CTWOFACTOR_STATUS_RESPONSE.fields_by_name['time_transferred']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['steamid']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['authenticator_time']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['serial_number']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['authenticator_type']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['device_identifier']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['sms_phone_id']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['http_headers']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST.fields_by_name['version']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['shared_secret']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['serial_number']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['revocation_code']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['uri']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['server_time']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['account_name']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['token_gid']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['identity_secret']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['secret_1']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['status']._options = None
_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE.fields_by_name['phone_number_hint']._options = None
_CTWOFACTOR_SENDEMAIL_REQUEST.fields_by_name['steamid']._options = None
_CTWOFACTOR_SENDEMAIL_REQUEST.fields_by_name['email_type']._options = None
_CTWOFACTOR_SENDEMAIL_REQUEST.fields_by_name['include_activation_code']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['steamid']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['authenticator_code']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['authenticator_time']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['activation_code']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['http_headers']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST.fields_by_name['validate_sms_code']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE.fields_by_name['success']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE.fields_by_name['want_more']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE.fields_by_name['server_time']._options = None
_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE.fields_by_name['status']._options = None
_CTWOFACTOR_UPDATETOKENVERSION_REQUEST.fields_by_name['version']._options = None
_CTWOFACTOR_UPDATETOKENVERSION_REQUEST.fields_by_name['signature']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST.fields_by_name['revocation_code']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST.fields_by_name['revocation_reason']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST.fields_by_name['steamguard_scheme']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST.fields_by_name['remove_all_steamguard_cookies']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE.fields_by_name['success']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE.fields_by_name['server_time']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE.fields_by_name['revocation_attempts_remaining']._options = None
_CTWOFACTOR_CREATEEMERGENCYCODES_RESPONSE.fields_by_name['codes']._options = None
_CTWOFACTOR_DESTROYEMERGENCYCODES_REQUEST.fields_by_name['steamid']._options = None
_CTWOFACTOR_VALIDATETOKEN_REQUEST.fields_by_name['code']._options = None
_CTWOFACTOR_VALIDATETOKEN_RESPONSE.fields_by_name['valid']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE.fields_by_name['success']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST.fields_by_name['sms_code']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST.fields_by_name['generate_new_token']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['shared_secret']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['serial_number']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['revocation_code']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['uri']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['server_time']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['account_name']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['token_gid']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['identity_secret']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['secret_1']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['status']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['steamguard_scheme']._options = None
_CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN.fields_by_name['steamid']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE.fields_by_name['success']._options = None
_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE.fields_by_name['replacement_token']._options = None

_TWOFACTOR = _descriptor.ServiceDescriptor(
  name='TwoFactor',
  full_name='TwoFactor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030!Two Factor Authentication Service',
  create_key=_descriptor._internal_create_key,
  serialized_start=5967,
  serialized_end=7818,
  methods=[
  _descriptor.MethodDescriptor(
    name='QueryStatus',
    full_name='TwoFactor.QueryStatus',
    index=0,
    containing_service=None,
    input_type=_CTWOFACTOR_STATUS_REQUEST,
    output_type=_CTWOFACTOR_STATUS_RESPONSE,
    serialized_options=b'\202\265\030@Get two-factor authentication settings for the logged-in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddAuthenticator',
    full_name='TwoFactor.AddAuthenticator',
    index=1,
    containing_service=None,
    input_type=_CTWOFACTOR_ADDAUTHENTICATOR_REQUEST,
    output_type=_CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE,
    serialized_options=b'\202\265\0305Add two-factor authenticator to the logged-in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendEmail',
    full_name='TwoFactor.SendEmail',
    index=2,
    containing_service=None,
    input_type=_CTWOFACTOR_SENDEMAIL_REQUEST,
    output_type=_CTWOFACTOR_SENDEMAIL_RESPONSE,
    serialized_options=b'\202\265\030\031Send email to the account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinalizeAddAuthenticator',
    full_name='TwoFactor.FinalizeAddAuthenticator',
    index=3,
    containing_service=None,
    input_type=_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST,
    output_type=_CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE,
    serialized_options=b'\202\265\030DFinalize two-factor authentication addition to the logged-in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTokenVersion',
    full_name='TwoFactor.UpdateTokenVersion',
    index=4,
    containing_service=None,
    input_type=_CTWOFACTOR_UPDATETOKENVERSION_REQUEST,
    output_type=_CTWOFACTOR_UPDATETOKENVERSION_RESPONSE,
    serialized_options=b'\202\265\030\037Update the version for my token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAuthenticator',
    full_name='TwoFactor.RemoveAuthenticator',
    index=5,
    containing_service=None,
    input_type=_CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST,
    output_type=_CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE,
    serialized_options=b'\202\265\030DRemove two-factor authentication addition from the logged-in account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEmergencyCodes',
    full_name='TwoFactor.CreateEmergencyCodes',
    index=6,
    containing_service=None,
    input_type=_CTWOFACTOR_CREATEEMERGENCYCODES_REQUEST,
    output_type=_CTWOFACTOR_CREATEEMERGENCYCODES_RESPONSE,
    serialized_options=b'\202\265\030&Generate emergency authenticator codes',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DestroyEmergencyCodes',
    full_name='TwoFactor.DestroyEmergencyCodes',
    index=7,
    containing_service=None,
    input_type=_CTWOFACTOR_DESTROYEMERGENCYCODES_REQUEST,
    output_type=_CTWOFACTOR_DESTROYEMERGENCYCODES_RESPONSE,
    serialized_options=b'\202\265\0305Destroy emergency authenticator codes for the account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateToken',
    full_name='TwoFactor.ValidateToken',
    index=8,
    containing_service=None,
    input_type=_CTWOFACTOR_VALIDATETOKEN_REQUEST,
    output_type=_CTWOFACTOR_VALIDATETOKEN_RESPONSE,
    serialized_options=b'\202\265\030\036Validate (and consume) a token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAuthenticatorViaChallengeStart',
    full_name='TwoFactor.RemoveAuthenticatorViaChallengeStart',
    index=9,
    containing_service=None,
    input_type=_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST,
    output_type=_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE,
    serialized_options=b'\202\265\030+Start challenge-based authenticator removal',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveAuthenticatorViaChallengeContinue',
    full_name='TwoFactor.RemoveAuthenticatorViaChallengeContinue',
    index=10,
    containing_service=None,
    input_type=_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST,
    output_type=_CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE,
    serialized_options=b'\202\265\030.Continue challenge-based authenticator removal',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TWOFACTOR)

DESCRIPTOR.services_by_name['TwoFactor'] = _TWOFACTOR

TwoFactor = service_reflection.GeneratedServiceType('TwoFactor', (_service.Service,), dict(
  DESCRIPTOR = _TWOFACTOR,
  __module__ = 'steammessages_twofactor_pb2'
  ))

TwoFactor_Stub = service_reflection.GeneratedServiceStubType('TwoFactor_Stub', (TwoFactor,), dict(
  DESCRIPTOR = _TWOFACTOR,
  __module__ = 'steammessages_twofactor_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_contentsystem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_contentsystem.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_contentsystem.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xb5\x02\n6CContentServerDirectory_GetServersForSteamPipe_Request\x12#\n\x07\x63\x65ll_id\x18\x01 \x01(\rB\x12\x82\xb5\x18\x0e\x63lient Cell ID\x12\x39\n\x0bmax_servers\x18\x02 \x01(\r:\x02\x32\x30\x42 \x82\xb5\x18\x1cmax servers in response list\x12*\n\x0bip_override\x18\x03 \x01(\tB\x15\x82\xb5\x18\x11\x63lient IP address\x12+\n\rlauncher_type\x18\x04 \x01(\x05:\x01\x30\x42\x11\x82\xb5\x18\rlauncher type\x12\x42\n\x0bipv6_public\x18\x05 \x01(\tB-\x82\xb5\x18)client public ipv6 address if it knows it\"\xdb\x02\n\"CContentServerDirectory_ServerInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x03 \x01(\x05\x12\x0c\n\x04load\x18\x04 \x01(\x05\x12\x15\n\rweighted_load\x18\x05 \x01(\x02\x12\"\n\x1anum_entries_in_client_list\x18\x06 \x01(\x05\x12\x18\n\x10steam_china_only\x18\x07 \x01(\x08\x12\x0c\n\x04host\x18\x08 \x01(\t\x12\r\n\x05vhost\x18\t \x01(\t\x12\x14\n\x0cuse_as_proxy\x18\n \x01(\x08\x12#\n\x1bproxy_request_path_template\x18\x0b \x01(\t\x12\x15\n\rhttps_support\x18\x0c \x01(\t\x12\x17\n\x0f\x61llowed_app_ids\x18\r \x03(\r\x12\x18\n\x10preferred_server\x18\x0e \x01(\x08\"o\n7CContentServerDirectory_GetServersForSteamPipe_Response\x12\x34\n\x07servers\x18\x01 \x03(\x0b\x32#.CContentServerDirectory_ServerInfo\"\x89\x01\n1CContentServerDirectory_GetDepotPatchInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x19\n\x11source_manifestid\x18\x03 \x01(\x04\x12\x19\n\x11target_manifestid\x18\x04 \x01(\x04\"{\n2CContentServerDirectory_GetDepotPatchInfo_Response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\x12\x12\n\npatch_size\x18\x02 \x01(\x04\x12\x1b\n\x13patched_chunks_size\x18\x03 \x01(\x04\"P\n4CContentServerDirectory_GetClientUpdateHosts_Request\x12\x18\n\x10\x63\x61\x63hed_signature\x18\x01 \x01(\t\"w\n5CContentServerDirectory_GetClientUpdateHosts_Response\x12\x10\n\x08hosts_kv\x18\x01 \x01(\t\x12\x18\n\x10valid_until_time\x18\x02 \x01(\x04\x12\x12\n\nip_country\x18\x03 \x01(\t\"\xa1\x01\n6CContentServerDirectory_GetManifestRequestCode_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x04\x12\x12\n\napp_branch\x18\x04 \x01(\t\x12\x1c\n\x14\x62ranch_password_hash\x18\x05 \x01(\t\"X\n7CContentServerDirectory_GetManifestRequestCode_Response\x12\x1d\n\x15manifest_request_code\x18\x01 \x01(\x04\x32\xe0\x04\n\x16\x43ontentServerDirectory\x12\x8b\x01\n\x16GetServersForSteamPipe\x12\x37.CContentServerDirectory_GetServersForSteamPipe_Request\x1a\x38.CContentServerDirectory_GetServersForSteamPipe_Response\x12|\n\x11GetDepotPatchInfo\x12\x32.CContentServerDirectory_GetDepotPatchInfo_Request\x1a\x33.CContentServerDirectory_GetDepotPatchInfo_Response\x12\x85\x01\n\x14GetClientUpdateHosts\x12\x35.CContentServerDirectory_GetClientUpdateHosts_Request\x1a\x36.CContentServerDirectory_GetClientUpdateHosts_Response\x12\x8b\x01\n\x16GetManifestRequestCode\x12\x37.CContentServerDirectory_GetManifestRequestCode_Request\x1a\x38.CContentServerDirectory_GetManifestRequestCode_Response\x1a$\x82\xb5\x18 Content Server and CDN directoryB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetServersForSteamPipe_Request',
  full_name='CContentServerDirectory_GetServersForSteamPipe_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.cell_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\016client Cell ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_servers', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.max_servers', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034max servers in response list', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_override', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.ip_override', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021client IP address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launcher_type', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.launcher_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\rlauncher type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_public', full_name='CContentServerDirectory_GetServersForSteamPipe_Request.ipv6_public', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)client public ipv6 address if it knows it', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=407,
)


_CCONTENTSERVERDIRECTORY_SERVERINFO = _descriptor.Descriptor(
  name='CContentServerDirectory_ServerInfo',
  full_name='CContentServerDirectory_ServerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CContentServerDirectory_ServerInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='CContentServerDirectory_ServerInfo.source_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CContentServerDirectory_ServerInfo.cell_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='CContentServerDirectory_ServerInfo.load', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_load', full_name='CContentServerDirectory_ServerInfo.weighted_load', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_entries_in_client_list', full_name='CContentServerDirectory_ServerInfo.num_entries_in_client_list', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_china_only', full_name='CContentServerDirectory_ServerInfo.steam_china_only', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='CContentServerDirectory_ServerInfo.host', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vhost', full_name='CContentServerDirectory_ServerInfo.vhost', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_as_proxy', full_name='CContentServerDirectory_ServerInfo.use_as_proxy', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_request_path_template', full_name='CContentServerDirectory_ServerInfo.proxy_request_path_template', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='https_support', full_name='CContentServerDirectory_ServerInfo.https_support', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_app_ids', full_name='CContentServerDirectory_ServerInfo.allowed_app_ids', index=12,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_server', full_name='CContentServerDirectory_ServerInfo.preferred_server', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=757,
)


_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetServersForSteamPipe_Response',
  full_name='CContentServerDirectory_GetServersForSteamPipe_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='CContentServerDirectory_GetServersForSteamPipe_Response.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=870,
)


_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetDepotPatchInfo_Request',
  full_name='CContentServerDirectory_GetDepotPatchInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depotid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.depotid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_manifestid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.source_manifestid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_manifestid', full_name='CContentServerDirectory_GetDepotPatchInfo_Request.target_manifestid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=1010,
)


_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetDepotPatchInfo_Response',
  full_name='CContentServerDirectory_GetDepotPatchInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_available', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.is_available', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch_size', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.patch_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patched_chunks_size', full_name='CContentServerDirectory_GetDepotPatchInfo_Response.patched_chunks_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1135,
)


_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetClientUpdateHosts_Request',
  full_name='CContentServerDirectory_GetClientUpdateHosts_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cached_signature', full_name='CContentServerDirectory_GetClientUpdateHosts_Request.cached_signature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1137,
  serialized_end=1217,
)


_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetClientUpdateHosts_Response',
  full_name='CContentServerDirectory_GetClientUpdateHosts_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts_kv', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.hosts_kv', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_until_time', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.valid_until_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_country', full_name='CContentServerDirectory_GetClientUpdateHosts_Response.ip_country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1338,
)


_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST = _descriptor.Descriptor(
  name='CContentServerDirectory_GetManifestRequestCode_Request',
  full_name='CContentServerDirectory_GetManifestRequestCode_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.depot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CContentServerDirectory_GetManifestRequestCode_Request.manifest_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_branch', full_name='CContentServerDirectory_GetManifestRequestCode_Request.app_branch', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_password_hash', full_name='CContentServerDirectory_GetManifestRequestCode_Request.branch_password_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1341,
  serialized_end=1502,
)


_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE = _descriptor.Descriptor(
  name='CContentServerDirectory_GetManifestRequestCode_Response',
  full_name='CContentServerDirectory_GetManifestRequestCode_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifest_request_code', full_name='CContentServerDirectory_GetManifestRequestCode_Response.manifest_request_code', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1592,
)

_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE.fields_by_name['servers'].message_type = _CCONTENTSERVERDIRECTORY_SERVERINFO
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetServersForSteamPipe_Request'] = _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_ServerInfo'] = _CCONTENTSERVERDIRECTORY_SERVERINFO
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetServersForSteamPipe_Response'] = _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetDepotPatchInfo_Request'] = _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetDepotPatchInfo_Response'] = _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetClientUpdateHosts_Request'] = _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetClientUpdateHosts_Response'] = _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetManifestRequestCode_Request'] = _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST
DESCRIPTOR.message_types_by_name['CContentServerDirectory_GetManifestRequestCode_Response'] = _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CContentServerDirectory_GetServersForSteamPipe_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetServersForSteamPipe_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetServersForSteamPipe_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetServersForSteamPipe_Request)

CContentServerDirectory_ServerInfo = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_ServerInfo', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_SERVERINFO,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_ServerInfo)
  })
_sym_db.RegisterMessage(CContentServerDirectory_ServerInfo)

CContentServerDirectory_GetServersForSteamPipe_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetServersForSteamPipe_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetServersForSteamPipe_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetServersForSteamPipe_Response)

CContentServerDirectory_GetDepotPatchInfo_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetDepotPatchInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetDepotPatchInfo_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetDepotPatchInfo_Request)

CContentServerDirectory_GetDepotPatchInfo_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetDepotPatchInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetDepotPatchInfo_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetDepotPatchInfo_Response)

CContentServerDirectory_GetClientUpdateHosts_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetClientUpdateHosts_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetClientUpdateHosts_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetClientUpdateHosts_Request)

CContentServerDirectory_GetClientUpdateHosts_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetClientUpdateHosts_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetClientUpdateHosts_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetClientUpdateHosts_Response)

CContentServerDirectory_GetManifestRequestCode_Request = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetManifestRequestCode_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetManifestRequestCode_Request)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetManifestRequestCode_Request)

CContentServerDirectory_GetManifestRequestCode_Response = _reflection.GeneratedProtocolMessageType('CContentServerDirectory_GetManifestRequestCode_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE,
  '__module__' : 'steammessages_contentsystem_pb2'
  # @@protoc_insertion_point(class_scope:CContentServerDirectory_GetManifestRequestCode_Response)
  })
_sym_db.RegisterMessage(CContentServerDirectory_GetManifestRequestCode_Response)


DESCRIPTOR._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['cell_id']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['max_servers']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['ip_override']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['launcher_type']._options = None
_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST.fields_by_name['ipv6_public']._options = None

_CONTENTSERVERDIRECTORY = _descriptor.ServiceDescriptor(
  name='ContentServerDirectory',
  full_name='ContentServerDirectory',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030 Content Server and CDN directory',
  create_key=_descriptor._internal_create_key,
  serialized_start=1595,
  serialized_end=2203,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetServersForSteamPipe',
    full_name='ContentServerDirectory.GetServersForSteamPipe',
    index=0,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETSERVERSFORSTEAMPIPE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDepotPatchInfo',
    full_name='ContentServerDirectory.GetDepotPatchInfo',
    index=1,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETDEPOTPATCHINFO_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClientUpdateHosts',
    full_name='ContentServerDirectory.GetClientUpdateHosts',
    index=2,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETCLIENTUPDATEHOSTS_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetManifestRequestCode',
    full_name='ContentServerDirectory.GetManifestRequestCode',
    index=3,
    containing_service=None,
    input_type=_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_REQUEST,
    output_type=_CCONTENTSERVERDIRECTORY_GETMANIFESTREQUESTCODE_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTENTSERVERDIRECTORY)

DESCRIPTOR.services_by_name['ContentServerDirectory'] = _CONTENTSERVERDIRECTORY

ContentServerDirectory = service_reflection.GeneratedServiceType('ContentServerDirectory', (_service.Service,), dict(
  DESCRIPTOR = _CONTENTSERVERDIRECTORY,
  __module__ = 'steammessages_contentsystem_pb2'
  ))

ContentServerDirectory_Stub = service_reflection.GeneratedServiceStubType('ContentServerDirectory_Stub', (ContentServerDirectory,), dict(
  DESCRIPTOR = _CONTENTSERVERDIRECTORY,
  __module__ = 'steammessages_contentsystem_pb2'
  ))


# @@protoc_insertion_point(module_scope)
